2023-09-19 Version: 2.0.0
- Generated python 2019-03-15 for adb.

2023-08-31 Version: 1.1.2
- Generated python 2019-03-15 for adb.

2023-08-22 Version: 1.1.1
- Generated python 2019-03-15 for adb.

2023-08-17 Version: 1.1.0
- Generated python 2019-03-15 for adb.

2022-05-26 Version: 1.0.11
- Support ModifyDBClusterPayType.

2022-01-05 Version: 1.0.10
- Move to perth for DescribeAuditLogRecords.
- Move to perth for DescribeAuditLogConfig.

2021-10-25 Version: 1.0.9
- CreateDBCluster Support ElasticResourceIO.

2021-05-14 Version: 1.0.8
- Update CreateDBCluster.
- Update ModifyDBCluster.

2021-03-31 Version: 1.0.7
- Generated python 2019-03-15 for adb.

2021-03-12 Version: 1.0.6
- Supportd DescribeTableStatisticsRequest.

